pub enum ConstitutionalContextStatus {
Missing,
Partial,
Complete,
}Expand description
Completeness status of the constitutional context payload on a review artifact.
Variants
Implementations
Sourceimpl ConstitutionalContextStatus
impl ConstitutionalContextStatus
Sourcepub fn is_complete(self) -> bool
pub fn is_complete(self) -> bool
Returns true only when the full constitutional context is present.