pub struct MethodPolicy {
pub method: CheckMethod,
pub allowed: bool,
pub max_autonomy: AutonomyCeiling,
pub approval_requirement: ApprovalRequirement,
}Fields
method: CheckMethodallowed: boolmax_autonomy: AutonomyCeilingapproval_requirement: ApprovalRequirementTrait Implementations
Sourceimpl Clone for MethodPolicy
impl Clone for MethodPolicy
Sourcefn clone(&self) -> MethodPolicy
fn clone(&self) -> MethodPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MethodPolicy
impl Debug for MethodPolicy
Sourceimpl<'de> Deserialize<'de> for MethodPolicy
impl<'de> Deserialize<'de> for MethodPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MethodPolicy
Sourceimpl JsonSchema for MethodPolicy
impl JsonSchema for MethodPolicy
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MethodPolicy
impl PartialEq for MethodPolicy
Sourcefn eq(&self, other: &MethodPolicy) -> bool
fn eq(&self, other: &MethodPolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MethodPolicy
impl Serialize for MethodPolicy
impl StructuralPartialEq for MethodPolicy