pub struct PolicyDecision {Show 16 fields
pub schema_version: String,
pub decision_id: PolicyDecisionId,
pub policy_version: String,
pub case_id: VerificationCaseId,
pub plan_id: CheckPlanId,
pub citation: V25CitationContext,
pub obligation_refs: V25ControlObligationRefs,
pub citation_status: ConstitutionalContextStatus,
pub obligation_refs_status: ConstitutionalContextStatus,
pub evaluated_at: String,
pub method_allowed: bool,
pub autonomy_allowed: bool,
pub promotion_allowed: bool,
pub approval_required: bool,
pub approval_satisfied: bool,
pub reasons: Vec<String>,
}Fields
schema_version: Stringdecision_id: PolicyDecisionIdpolicy_version: Stringcase_id: VerificationCaseIdplan_id: CheckPlanIdcitation: V25CitationContextobligation_refs: V25ControlObligationRefscitation_status: ConstitutionalContextStatusobligation_refs_status: ConstitutionalContextStatusevaluated_at: Stringmethod_allowed: boolautonomy_allowed: boolpromotion_allowed: boolapproval_required: boolapproval_satisfied: boolreasons: Vec<String>Implementations
Sourceimpl PolicyDecision
impl PolicyDecision
Sourcepub fn issue_execution_permit(
&self,
case: &VerificationCase,
plan: &CheckPlan,
approvals: &[ApprovalRecord],
) -> Result<ExecutionPermit, PermitIssuanceError>
pub fn issue_execution_permit( &self, case: &VerificationCase, plan: &CheckPlan, approvals: &[ApprovalRecord], ) -> Result<ExecutionPermit, PermitIssuanceError>
Mints a sealed execution permit when the policy decision still authorizes one promotable execution for the supplied case and plan.