pub struct CommitToken { /* private fields */ }Implementations
Sourceimpl CommitToken
impl CommitToken
Sourcepub fn execution_permit_id(&self) -> &ExecutionPermitId
pub fn execution_permit_id(&self) -> &ExecutionPermitId
Runtime-only commit tokens cannot be forged outside this crate.
ⓘ
use stack_ids::{ExecutionPermitId, PolicyDecisionId};
use verification_policy::CommitToken;
let _forged = CommitToken {
execution_permit_id: ExecutionPermitId::new("permit-1"),
decision_id: PolicyDecisionId::new("decision-1"),
};Returns the permit identifier bound to this runtime token.
Sourcepub fn decision_id(&self) -> &PolicyDecisionId
pub fn decision_id(&self) -> &PolicyDecisionId
Returns the policy decision that minted this runtime token.